function [fitresult, gof] = createFit(Airspeed, Bankangle, vspeed, fit_1, K)
%CREATEFIT(AIRSPEED,BANKANGLE,VSPEED,FIT_1)
%  Create a fit.
%
%  Data for 'SpeedPolar' fit:
%      X Input : Airspeed
%      Y Input : Bankangle
%      Z Output: vspeed
%      Weights : fit
%  Output:
%      fitresult : a fit object representing the fit.
%      gof : structure with goodness-of fit info.
%
%  See also FIT, CFIT, SFIT.

%  Auto-generated by MATLAB on 16-May-2021 07:30:51


%% Fit: 'SpeedPolar'.
[xData, yData, zData, weights] = prepareSurfaceData( Airspeed, Bankangle, vspeed, fit_1 );

% Set up fittype and options.
ft = fittype( '-Airspeed*((CD0*Airspeed^2)/K + (B*K)/(Airspeed^2*(Bankangle^2/2 - 1)^2))', 'independent', {'Airspeed', 'Bankangle'}, 'dependent', 'z' );
opts = fitoptions( 'Method', 'NonlinearLeastSquares' );
opts.Algorithm = 'Trust-Region';
opts.DiffMinChange = 1e-16;
opts.Display = 'Off';
opts.Lower = [0 0 0];
opts.MaxFunEvals = 99999;
opts.MaxIter = 99999;
opts.Robust = 'Bisquare';
opts.StartPoint = [0 0 K];
opts.TolFun = 1e-12;
opts.TolX = 1e-12;
opts.Weights = weights;

% Fit model to data.
[fitresult, gof] = fit( [xData, yData], zData, ft, opts );

% Create a figure for the plots.
figure( 'Name', 'SpeedPolar' );

% Plot fit with data.
subplot( 2, 2, 2 );
h = plot( fitresult, [xData, yData], zData );
legend( h, 'SpeedPolar', 'vspeed vs. Airspeed, Bankangle with fit', 'Location', 'NorthEast', 'Interpreter', 'none' );
% Label axes
xlabel( 'Airspeed', 'Interpreter', 'none' );
ylabel( 'Bankangle', 'Interpreter', 'none' );
zlabel( 'vspeed', 'Interpreter', 'none' );
grid on

% Plot residuals.
subplot( 2, 2, 4 );
h = plot( fitresult, [xData, yData], zData, 'Style', 'Residual' );
legend( h, 'SpeedPolar - residuals', 'Location', 'NorthEast', 'Interpreter', 'none' );
% Label axes
xlabel( 'Airspeed', 'Interpreter', 'none' );
ylabel( 'Bankangle', 'Interpreter', 'none' );
zlabel( 'vspeed', 'Interpreter', 'none' );
grid on

% Make contour plot.
subplot( 1, 2, 1 );
h = plot( fitresult, [xData, yData], zData, 'Style', 'Contour' );
legend( h, 'SpeedPolar', 'vspeed vs. Airspeed, Bankangle with fit', 'Location', 'NorthEast', 'Interpreter', 'none' );
% Label axes
xlabel( 'Airspeed', 'Interpreter', 'none' );
ylabel( 'Bankangle', 'Interpreter', 'none' );
grid on




